use actix_identity::Identity;
use actix_web::{web, HttpResponse, Responder};
use askama::Template;
use askama_actix::TemplateToResponse;
use sqlx::PgPool;

use crate::models::{Area, Location, Role, User};

#[derive(Template)]
#[template(path = "location/overview.html")]
pub struct LocationsTemplate {
    user: User,
    grouped_locations: Vec<(Area, Vec<Location>)>
}

#[actix_web::get("/locations")]
pub async fn get(user: Identity, pool: web::Data<PgPool>) -> impl Responder {
    let current_user = User::read_by_id(pool.get_ref(), user.id().unwrap().parse().unwrap()).await.unwrap();

    if current_user.role == Role::AreaManager || current_user.role == Role::Admin {
        let mut locations;

        if current_user.role == Role::Admin {
            locations = Location::read_all_including_area(pool.get_ref()).await.unwrap();
        } else {
            locations = Location::read_by_area(pool.get_ref(), current_user.area_id).await.unwrap();
        }

        let mut grouped_locations = Vec::new();

        let areas: Vec<Area> = locations.iter().map(|l| l.area.clone().unwrap()).collect();

        for area in areas {
            let (locations_in_this_area, rest): (Vec<_>, Vec<_>) = locations.into_iter().partition(|l| l.area_id == area.id);
            locations = rest;

            grouped_locations.push((area, locations_in_this_area))
        }

        let template = LocationsTemplate { user: current_user, grouped_locations };

        return template.to_response()
    }

    return HttpResponse::Unauthorized().finish();
}
