use actix_identity::Identity;
use actix_web::{http::header::LOCATION, web, HttpResponse, Responder};
use serde::Deserialize;
use sqlx::PgPool;

use crate::models::{Location, Role, User};

#[derive(Deserialize)]
pub struct NewLocationForm {
    name: String,
    area: Option<i32>,
}

#[actix_web::post("/locations/new")]
pub async fn post(user: Identity, pool: web::Data<PgPool>, form: web::Form<NewLocationForm>) -> impl Responder {
    let current_user = User::read_by_id(pool.get_ref(), user.id().unwrap().parse().unwrap())
        .await
        .unwrap();

    if current_user.role == Role::AreaManager || current_user.role == Role::Admin {
        let mut area_id = current_user.area_id;

        if current_user.role == Role::Admin && form.area.is_some() {
            area_id = form.area.unwrap();
        }

        match Location::create(pool.get_ref(), &form.name, area_id).await {
            Ok(_) => return HttpResponse::Found().insert_header((LOCATION, "/locations")).finish(),
            Err(err) => println!("{}", err)
        }
    }

    return HttpResponse::Unauthorized().finish();
}
